#
# spec file for package python-ssdeep
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-ssdeep
Version:        3.4.1
Release:        1.6
Summary:        Python wrapper for the ssdeep library
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/DinoTools/python-ssdeep
#Source:         https://files.pythonhosted.org/packages/source/s/ssdeep/ssdeep-%%{version}.tar.gz # no docs here, see https://github.com/DinoTools/python-ssdeep/issues/37
Source:         https://github.com/DinoTools/python-ssdeep/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# https://github.com/DinoTools/python-ssdeep/commit/6cf96d63e9512fa14b6557d0d8afaa5128e0e853
Patch0:         python-ssdeep-no-six.patch
BuildRequires:  %{python_module cffi >= 0.8.6}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  libfuzzy-devel
BuildRequires:  python-rpm-macros
Requires:       python-cffi
Requires:       ssdeep
# SECTION tests
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A Python wrapper for ssdeep, which is a library for computing context triggered piecewise hashes (CTPH). Also called fuzzy hashes, CTPH can match inputs that have homologies. Such inputs
have sequences of identical bytes in the same order, although bytes in between these sequences may be different in both
content and length.

%prep
%setup -q -n python-ssdeep-%{version}
%patch0 -p1
# https://github.com/DinoTools/python-ssdeep/issues/57
sed -i 's:"pytest-runner.*"::' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%{python_sitearch}/ssdeep
%{python_sitearch}/ssdeep-*egg-info
%doc README.rst CHANGELOG.rst
%license LICENSE

%changelog
* Fri Nov 11 2022 pgajdos@suse.com
- silent rpmlint
* Fri Nov 11 2022 pgajdos@suse.com
- version update to 3.4.1
  * Add internal build improvements
  * Update CI pipelines
- do not require python-six
- added patches
  fix https://github.com/DinoTools/python-ssdeep/commit/6cf96d63e9512fa14b6557d0d8afaa5128e0e853
  + python-ssdeep-no-six.patch
* Tue Dec  7 2021 pgajdos@suse.com
- do not require pytest-runner for build, it is not needed
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- add missing six dependency declaration
* Wed Jan 13 2021 pgajdos@suse.com
- use %%pytest_arch macro
* Wed Jun  3 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- Disable Python 2 build because build dependencies do not resolve.
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not generate docu, fails with new sphinx and till now used
  py2 version for that
* Tue Mar 17 2020 pgajdos@suse.com
- version update to 3.4
  * Update documentation
  * Replace Jenkins and Travis CI with Drone CI
  * Add new copy() function to Hash() and PseudoHash() class
  * Add new attributes to Hash() and PseudoHash() class
  * name
  * block_size
* Thu Aug  2 2018 sebix+novell.com@sebix.at
- initial package for version 3.3
